==> 3.1.0.tar.gz: lib/src/prototype_controller.dart <==
import 'package:dotup_flutter_simulator/dotup_flutter_simulator.dart';
import 'package:flutter/material.dart';

import 'prototype_descriptor.dart';
import 'prototype_page_descriptor.dart';

class PrototypeController extends ChangeNotifier {
  PrototypeController({
    required this.descriptor,
    PageController? pageController,
    required this.simulatorController,
  }) {
    this.pageController = pageController ?? PageController();
  }

  // final List<MockupDescriptor> pages;
  late final PageController pageController;
  final PrototypeDescriptor descriptor;
  final SimulatorController simulatorController;

  bool _pageMenuVisible = false;
  bool get pageMenuVisible => _pageMenuVisible;
  bool _pageInfosVisible = true;
  bool get pageInfosVisible => _pageInfosVisible;

  bool _splashScreenVissible = true;
  bool get splashScreenVissible => _splashScreenVissible;
  set splashScreenVissible(bool value) {
    _splashScreenVissible = false;
    notifyListeners();
  }

  int _currentPage = -1;

  int get currentPageIndex => _currentPage;

  PrototypePageDescriptor get currentPage => descriptor.pages[_currentPage];

  WidgetBuilder getBuilder(int index) => descriptor.pages[index].builder;

  void setCurrentIndex(int number) {
    if (number == _currentPage) {
      return;
    }
    _currentPage = number;
    _pageMenuVisible = false;

    // _pageInfosVisible = true;
    // notifyListeners();
  }

  // Future<void> toNextPage() async {
  //   _currentPage += 1;
  // }

  Future<void> toPage(int pageNumber) async {
    _currentPage = pageNumber;
    // pageController.animateToPage(pageNumber, duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    pageController.jumpToPage(pageNumber); //, duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    _pageMenuVisible = false;
    _pageInfosVisible = true;
    notifyListeners();
    simulatorController.updateOverlay();
    // MockupPresenter.showPageInfo(this);
  }

  // Future<void> toNamedPage(String title) async {}

  void showPageInfos() {
    _pageInfosVisible = true;
    notifyListeners();
  }

  void hidePageInfos() {
    _pageInfosVisible = false;
    notifyListeners();
  }

  void showPageMenu() {
    _pageMenuVisible = true;
    notifyListeners();
  }

  void hidePageMenu() {
    _pageMenuVisible = false;
    notifyListeners();
  }
}

==> 3.1.2.tar.gz: lib/src/prototype_controller.dart <==
import 'package:dotup_flutter_simulator/dotup_flutter_simulator.dart';
import 'package:flutter/material.dart';

import 'prototype_descriptor.dart';
import 'prototype_page_descriptor.dart';

class PrototypeController extends ChangeNotifier {
  PrototypeController({
    required this.descriptor,
    PageController? pageController,
    this.simulatorController,
  }) {
    this.pageController = pageController ?? PageController();
  }

  // final List<MockupDescriptor> pages;
  late final PageController pageController;
  final PrototypeDescriptor descriptor;
  final SimulatorController? simulatorController;

  bool _pageMenuVisible = false;
  bool get pageMenuVisible => _pageMenuVisible;
  bool _pageInfosVisible = true;
  bool get pageInfosVisible => _pageInfosVisible;

  bool _splashScreenVissible = true;
  bool get splashScreenVissible => _splashScreenVissible;
  set splashScreenVissible(bool value) {
    _splashScreenVissible = false;
    notifyListeners();
  }

  int _currentPage = -1;

  int get currentPageIndex => _currentPage;

  PrototypePageDescriptor get currentPage => descriptor.pages[_currentPage];

  WidgetBuilder getBuilder(int index) => descriptor.pages[index].builder;

  void setCurrentIndex(int number) {
    if (number == _currentPage) {
      return;
    }
    _currentPage = number;
    _pageMenuVisible = false;

    // _pageInfosVisible = true;
    // notifyListeners();
  }

  // Future<void> toNextPage() async {
  //   _currentPage += 1;
  // }

  Future<void> toPage(int pageNumber) async {
    _currentPage = pageNumber;
    // pageController.animateToPage(pageNumber, duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    pageController.jumpToPage(pageNumber); //, duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    _pageMenuVisible = false;
    _pageInfosVisible = true;
    notifyListeners();
    simulatorController?.updateOverlay();
    // MockupPresenter.showPageInfo(this);
  }

  // Future<void> toNamedPage(String title) async {}

  void showPageInfos() {
    _pageInfosVisible = true;
    notifyListeners();
  }

  void hidePageInfos() {
    _pageInfosVisible = false;
    notifyListeners();
  }

  void showPageMenu() {
    _pageMenuVisible = true;
    notifyListeners();
  }

  void hidePageMenu() {
    _pageMenuVisible = false;
    notifyListeners();
  }
}
